@@ -8,6 +8,7 @@ mod job_status;
 mod jobs_status;
 mod list_item;
 mod media_segment;
+mod notification;
 mod parameter;
 mod parameter_type;
 mod requirement;
@@ -30,6 +31,7 @@ pub use job_status::JobStatus;
 pub use jobs_status::JobsStatus;
 pub use list_item::ListItem;
 pub use media_segment::MediaSegment;
+pub use notification::Notification;
 pub use parameter::Parameter;
 pub use parameter_type::ParameterType;
 pub use requirement::Requirement;
